@@ -1,4 +1,7 @@
+#!/usr/bin/perl -w
+
+use strict;
+
 use Test::Unit::TkTestRunner;
+
 Test::Unit::TkTestRunner::main(@ARGV);
-
-
