@@ -2,24 +2,26 @@ package Test::Unit::Assertion;
 
 use strict;
 
-require Test::Unit::ExceptionFailure;
+use Carp;
+use Test::Unit::Failure;
+
+use overload '""' => 'to_string';
 
 sub fail {
     my $self = shift;
-    local $^W;
-    my $message = join '', @_;
-    my $exception = Test::Unit::ExceptionFailure->new($message);
-    $exception->hide_backtrace;
-    die $exception;
+    my($asserter, $file, $line) = caller(2); # We're always called from
+                                             # within an Assertion...
+    Test::Unit::Failure->throw(-object => $self,
+                               -file   => $file,
+                               -line   => $line,
+                               -text   => join '', @_);
 }
 
 sub do_assertion {
-    require Carp;
     Carp::croak("$_[0] forgot to override do_assertion");
 }
 
 sub new {
-    require Carp;
     Carp::croak("$_[0] forgot to override new");
 }
 
@@ -56,7 +58,7 @@ with an object as its first argument then it does:
 
 This means that C<do_assertion> should return true if the assertion
 succeeds and false if it doesn't. Or, you can fail by throwing a
-Test::Unit::ExceptionFailure object, which will get caught further up
+Test::Unit::Failure object, which will get caught further up
 the stack and used to produce a sensible error report. Generally it's
 good practice for do_assertion to die with a meaningful error on
 assertion failure rather than just returning false.
