@@ -1,6 +1,7 @@
 package Test::Unit::Assertion::Regexp;
 
 use strict;
+use Test::Unit::Assertion;
 use base qw/Test::Unit::Assertion/;
 
 sub new {
@@ -13,8 +14,13 @@ sub new {
 sub do_assertion {
     my $self = shift;
     my $target = shift;
-    $target =~ $$self ||
-        $self->fail("'$target' did not match /$$self/");
+    $target =~ $$self or
+        $self->fail(@_ ? $_[0] : "'$target' did not match /$$self/");
+}
+
+sub to_string {
+    my $self = shift;
+    "/$$self/ regexp assertion";
 }
 
 1;
